ADstat: The Anderson–Darling (AD) statistic for the two-parameter...

View source: R/ADstat.R

ADstatR Documentation

The Anderson–Darling (AD) statistic for the two-parameter exponential distribution.

Description

The Anderson–Darling statistic, called the AD statistic, measures the weighted distance between an empirical cumulative distribution function (ECDF) and a theoretical cumulative distribution function (CDF).

Usage

ADstat(x, theta, beta)

Arguments

x

a data vector (e.g., failure time, waiting time, etc.)

theta

location parameter, where \theta > 0.

beta

scale parameter, where \beta > 0 and rate=1/\beta.

Value

A value of the AD statistic.

References

D'Agostino, R. B., & Stephens, M. A. (Eds.). (1986). Goodness-of-fit techniques. Marcel Dekker. (ISBN 0-8247-8705-6).

Examples

# Proschan (1963, Table I) has given some samples of data,
# consisting of intervals between failures of air conditioning equipment in aircraft
data <- c(12,21,26,27,29,29,48,57,59,70,74,153,326,386,502)
theta_hat <- min(data)           #estimate theta
beta_hat <- mean(data)-min(data) #estimate beta
ADstat(data, theta_hat, beta_hat)


twopexp documentation built on July 17, 2026, 9:07 a.m.

Related to ADstat in twopexp...