Dstat: The Kolmogorov-Smirnov statistic (D statistic) for the...

View source: R/Dstat.R

DstatR Documentation

The Kolmogorov-Smirnov statistic (D statistic) for the two-parameter exponential distribution.

Description

The Kolmogorov-Smirnov statistic, also called the D statistic, measures the maximum vertical distance between the empirical distribution function (ECDF) of a sample of data and the CDF of a reference distribution. In this case, a reference distribution is the two-parameter exponential distribution.

Usage

Dstat(x, theta, beta)

Arguments

x

a data vector (e.g., failure time, waiting time, etc.)

theta

location parameter, where \theta > 0.

beta

scale parameter, where \beta > 0 and rate=1/\beta.

Value

A value of the D statistic.

References

D'Agostino, R. B., & Stephens, M. A. (Eds.). (1986). Goodness-of-fit techniques. Marcel Dekker. (ISBN 0-8247-8705-6).

Examples

# Proschan (1963, Table I) has given some samples of data,
# consisting of intervals between failures of air conditioning equipment in aircraft
data <- c(12,21,26,27,29,29,48,57,59,70,74,153,326,386,502)
theta_hat <- min(data)           #estimate theta
beta_hat <- mean(data)-min(data) #estimate beta
Dstat(data, theta_hat, beta_hat)


twopexp documentation built on July 17, 2026, 9:07 a.m.

Related to Dstat in twopexp...