Learn R Programming

twopexp (version 0.1.0)

medrank: Median rank method to estimate parameters of the two-parameter exponential dist.

Description

Median rank method to estimate parameters of the two-parameter exponential dist.

Usage

medrank(x, methods = c("B"))

Value

the estimate three values for the two-parameter exponential dist. as follows: theta.hat gives the estimate location parameter, beta.hat gives the estimate scale parameter, and lamda.hat gives the estimate the rate.

Arguments

x

vector of quantile (or a data set).

methods

there are some of median rank methods as follows; "B" stand for Benard median rank method (default), "BL" stand for Blom method, "MKM" stand for Hazen (Modified Kaplan Meier) method, "OT" stand for The one-third method, and "C" stand for Cunane method

Examples

Run this code
x1 <- c(25,43,53,65,76,86,95,115,132,150) # test a data set
medrank(x1,"B")    # Benard method (default) or medrank(x1)

Run the code above in your browser using DataLab