Learn R Programming

twopexp (version 0.1.0)

qm_tpexp: Quartile method estimation of the two-parameter exponential distribution

Description

To estimate the location (or shift) and scale parameters for the two-parameter exponential distribution based on quartile method. See detail in source

Usage

qm_tpexp(x, methods = c("Q13"))

Value

the estimate three values for the two-parameter exponential dist. as follows: qmtheta.hat gives the estimate location parameter, qmbeta.hat gives the estimate scale parameter, and qmlamda.hat gives the estimate the rate.

Arguments

x

vector of quantile (or a data set).

methods

there are two quartile methods as follows; "Q13" stand for the first and the third quartile method (default), and "Q12" stand for the first and the second quartile (median) method.

Examples

Run this code
x1 <- c(25,43,53,65,76,86,95,115,132,150) # test a data set
qm_tpexp(x1,"Q13")  # or qm_tpexp(x1)
qm_tpexp(x1,"Q12")

Run the code above in your browser using DataLab