| CMstat | R Documentation |
The Cramér-von Mises statistic measures the total squared distance between an empirical distribution function (ECDF) and a reference cumulative distribution function (CDF).
CMstat(x, theta, beta)
x |
a data vector (e.g., failure time, waiting time, etc.) |
theta |
location parameter, where |
beta |
scale parameter, where |
A value of the Cramér-von Mises statistic.
D'Agostino, R. B., & Stephens, M. A. (Eds.). (1986). Goodness-of-fit techniques. Marcel Dekker. (ISBN 0-8247-8705-6).
# Proschan (1963, Table I) has given some samples of data,
# consisting of intervals between failures of air conditioning equipment in aircraft
data <- c(12,21,26,27,29,29,48,57,59,70,74,153,326,386,502)
theta_hat <- min(data) #estimate theta
beta_hat <- mean(data)-min(data) #estimate beta
CMstat(data, theta_hat, beta_hat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.