qm_tpexp: Quartile method estimation of the two-parameter exponential distribution
Description
To estimate the location (or shift) and scale parameters for the two-parameter exponential distribution
based on quartile method. See detail in source
Usage
qm_tpexp(x, methods = c("Q13"))
Value
the estimate three values for the two-parameter exponential dist. as follows:
qmtheta.hat gives the estimate location parameter,
qmbeta.hat gives the estimate scale parameter,
and qmlamda.hat gives the estimate the rate.
Arguments
x
vector of quantile (or a data set).
methods
there are two quartile methods as follows;
"Q13" stand for the first and the third quartile method (default), and
"Q12" stand for the first and the second quartile (median) method.